Modules
======================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   model
   data

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
